<?php

/**
 * @version     1.0.0
 * @package     com_geommunity3cb
 * @copyright   Copyright (C) 2016. Adrien ROUSSEL Nordmograph.com All rights reserved.
 * @license     GNU General Public License version 3 or later; see LICENSE.txt
 * @author      Nordmograph <contact@nordmograph.com> - https://www.nordmograph.com./extensions
 */
defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

/**
 * Methods supporting a list of Geommunity3cb records.
 */
class Geommunity3cbModelMaps extends JModelList {

    /**
     * Constructor.
     *
     * @param    array    An optional associative array of configuration settings.
     * @see        JController
     * @since    1.6
     */
    public function __construct($config = array()) {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id', 'a.id',
                'title', 'a.title',
                'def_lat', 'a.def_lat',
                'def_lng', 'a.def_lng',
                'show_users', 'a.show_users',            
                'onlineonly', 'a.onlineonly',
                'avatarmarker', 'a.avatarmarker',
                'thirdparty', 'a.thirdparty',               
                'kmlurl', 'a.kmlurl',
                'privacyaware', 'a.privacyaware',
                'ordering', 'a.ordering',
                'state', 'a.state',
                'created_by', 'a.created_by',

            );
        }

        parent::__construct($config);
    }

    /**
     * Method to auto-populate the model state.
     *
     * Note. Calling getState in this method will result in recursion.
     */
    protected function populateState($ordering = null, $direction = null) {
        // Initialise variables.
        $app = JFactory::getApplication('administrator');

        // Load the filter state.
        $search = $app->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
        $this->setState('filter.search', $search);

        $published = $app->getUserStateFromRequest($this->context . '.filter.state', 'filter_published', '', 'string');
        $this->setState('filter.state', $published);

        
		//Filtering show_users
		$this->setState('filter.show_users', $app->getUserStateFromRequest($this->context.'.filter.show_users', 'filter_show_users', '', 'string'));

		//Filtering onlineonly
		$this->setState('filter.onlineonly', $app->getUserStateFromRequest($this->context.'.filter.onlineonly', 'filter_onlineonly', '', 'string'));


        // Load the parameters.
        $params = JComponentHelper::getParams('com_geommunity3cb');
        $this->setState('params', $params);

        // List state information.
        parent::populateState('a.id', 'asc');
    }

    /**
     * Method to get a store id based on model configuration state.
     *
     * This is necessary because the model is used by the component and
     * different modules that might need different sets of data or different
     * ordering requirements.
     *
     * @param	string		$id	A prefix for the store id.
     * @return	string		A store id.
     * @since	1.6
     */
    protected function getStoreId($id = '') {
        // Compile the store id.
        $id.= ':' . $this->getState('filter.search');
        $id.= ':' . $this->getState('filter.state');

        return parent::getStoreId($id);
    }

    /**
     * Build an SQL query to load the list data.
     *
     * @return	JDatabaseQuery
     * @since	1.6
     */
    protected function getListQuery() {
        // Create a new query object.
        $db = $this->getDbo();
        $query = $db->getQuery(true);

        // Select the required fields from the table.
        $query->select(
                $this->getState(
                        'list.select', 'a.*'
                )
        );
        $query->from('`#__geommunity3cb_maps` AS a');

        
		// Join over the users for the checked out user
		$query->select("uc.name AS editor");
		$query->join("LEFT", "#__users AS uc ON uc.id=a.checked_out");
		// Join over the user field 'created_by'
		$query->select('created_by.name AS created_by');
		$query->join('LEFT', '#__users AS created_by ON created_by.id = a.created_by');

        

		// Filter by published state
		$published = $this->getState('filter.state');
		if (is_numeric($published)) {
			$query->where('a.state = ' . (int) $published);
		} else if ($published === '') {
			$query->where('(a.state IN (0, 1))');
		}

        // Filter by search in title
        $search = $this->getState('filter.search');
        if (!empty($search)) {
            if (stripos($search, 'id:') === 0) {
                $query->where('a.id = ' . (int) substr($search, 3));
            } else {
                $search = $db->Quote('%' . $db->escape($search, true) . '%');
                
            }
        }

        

		//Filtering show_users
		$filter_show_users = $this->state->get("filter.show_users");
		if ($filter_show_users != '') {
			$query->where("a.show_users = '".$db->escape($filter_show_users)."'");
		}

		//Filtering onlineonly
		$filter_onlineonly = $this->state->get("filter.onlineonly");
		if ($filter_onlineonly != '') {
			$query->where("a.onlineonly = '".$db->escape($filter_onlineonly)."'");
		}

        // Add the list ordering clause.
        $orderCol = $this->state->get('list.ordering');
        $orderDirn = $this->state->get('list.direction');
        if ($orderCol && $orderDirn) {
            $query->order($db->escape($orderCol . ' ' . $orderDirn));
        }

        return $query;
    }

    public function getItems()
	{
		$items = parent::getItems();

		foreach ($items as $oneItem) {

			if (isset($oneItem->thirdparty)) {
				$values = explode(',', $oneItem->thirdparty);

				$textValue = array();
				foreach ($values as $value){
					if(!empty($value)){
						$db = JFactory::getDbo();
						$query = "SELECT element FROM #__extensions 
						WHERE type='plugin' AND enabled='1' AND  folder='geommunity' 
						HAVING element LIKE '" . $value . "'";
						$db->setQuery($query);
						$results = $db->loadObject();
						if ($results) {
							$textValue[] = $results->element;
						}
					}
				}

			$oneItem->thirdparty = !empty($textValue) ? implode(', ', $textValue) : $oneItem->thirdparty;

			}
		}
		return $items;
	}


}
